import { App } from "vue";
import { DynamicModalOptions, VueFinalModalProperty } from "vue-final-modal";
import { Router } from "vue-router";
export declare type HistoryModalPluginOption = {
    modal: VueFinalModalProperty;
    router: Router;
};
/**
 * 반드시 `setup()` 함수 내에서 호출되어야 한다.
 */
export declare const useHistoryModal: () => HistoryModal;
declare class HistoryModal {
    readonly modal: VueFinalModalProperty;
    readonly router: Router;
    private unregisterRouterBeforeEach?;
    private openModals;
    constructor(modal: VueFinalModalProperty, router: Router);
    private initialize;
    private removeAllModalFragments;
    private getModalFragments;
    private removeModalFragment;
    private appendModalFragment;
    show(option: DynamicModalOptions, params?: Record<string, unknown>): Promise<void>;
    hide(modalName: string): Promise<void>;
    private handleClose;
    hideAllModals(): Promise<void>;
    getOpenModalKeys(): string[];
}
/**
 * ```ts
 * createApp(GuideMain)
 *     .use(router)
 *     .use(ModalPlugin)
 *     .use(HistoryModalPlugin, {router, modal: ModalPlugin.modal})
 * ```
 */
export declare const HistoryModalPlugin: {
    install(app: App, option?: HistoryModalPluginOption): void;
};
/**
 * historyModal 이 열려있으면 router.back() 후 action 을 실행하고,
 * 그렇지 않으면 곧바로 action 을 실행한다.
 * @param historyModal
 * @param router
 * @param action
 */
export declare const closeHistoryModalAndDo: (historyModal: HistoryModal, router: Router, action: () => unknown) => Promise<void>;
export {};
